@@ -1,7 +1,7 @@
 package File::RsyBak;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-10-21'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -382,7 +382,7 @@ File::RsyBak - Backup files/directories with histories, using rsync
 
 =head1 VERSION
 
-This document describes version 0.27 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-09-03.
+This document describes version 0.28 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-10-21.
 
 =head1 SYNOPSIS
 
@@ -506,6 +506,18 @@ Backup files/directories with histories, using rsync.
 Examples:
 
  backup( source => "/home/jajang/mydata", target => "/backup/jajang/mydata");
+
+
+Result:
+
+ [
+   500,
+   "Error: Can't create target directory : No such file or directory",
+ ]
+
+
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
